@@ -599,13 +599,22 @@ function cust_pget($url,$storeDir,
   //広告の削除
   if( readConfig("RMADLINK") )
   {
+    $convHtml = preg_replace(
+      "/<div class=[\"\']thre[\"\']/",
+      '<span class="thre"',$convHtml);
+    
     $convHtml = pgetRmTag($convHtml, 'div', true);
-    $result = pgetParseHtml($convHtml, '/div', 'cnvNone', "");
+    $result   = pgetParseHtml($convHtml, '/div', 'cnvNone', "");
     $convHtml = $result[0];
     
     $convHtml = pgetRmTag($convHtml, 'iframe', true);
   }
-
+  
+  //mailtoの展開
+  $convHtml = preg_replace(
+    "/<a href=[\"\']mailto:([^\"^\']*)[\"\']>([^<]*)<\/a>/",
+    "$2 <font color=green>$1</font>",$convHtml);
+  
   //画像一覧を通知
   $imageUrls = array();
   foreach($convResults as $ret){
